@@ -114,14 +114,15 @@ def _files(source):
     else :
          yield open(source, 'rb')
 
-def put(source, dest, tar=False, *args, **kwargs):
+def put(source, dest, tar=False, *args, **kwargs):a
+    result = None
     if tar:
         tmp = uuid.uuid1()
         tmpsourcepath = "%s/%s.tar.gz" % (os.path.dirname(source), tmp)
         tar(source, tmpsourcepath)
 
     with settings(warn_only=True):
-        api.put(tmpsourcepath, dest, *args, **kwargs)
+        result = api.put(tmpsourcepath, dest, *args, **kwargs)
 
     if tar:
         tmpdestpath = "%s/%s.tar.gz" % (dest, tmp)
@@ -130,15 +131,18 @@ def put(source, dest, tar=False, *args, **kwargs):
         local('rm -fr %s' % tmpsourcepath)
         run('rm -fr %s' % tmpdestpath)
 
+    return result
+
 
 def get(source, dest, tar=False, *args, **kwargs):
+    result = None
     if tar:
         tmp = uuid.uuid1()
         tmpsourcepath = "%s/%s.tar.gz" % (os.path.dirname(source), tmp)
         tar(source, tmpsourcepath, local_use=False)
 
     with settings(warn_only=True):
-        api.get(tmpsourcepath, dest, *args, **kwargs)
+        result = api.get(tmpsourcepath, dest, *args, **kwargs)
 
     if tar:
         tmpdestpath = "%s/%s.tar.gz" % (dest, tmp)
@@ -146,6 +150,7 @@ def get(source, dest, tar=False, *args, **kwargs):
 
         local('rm -fr %s' % tmpdestpath)
         run('rm -fr %s' % tmpsourcepath)
+    return result
 
 def firewall(flag=True):
     #/usr/sbin/
